#
# spec file for package python-slixmpp
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%define _name   slixmpp
%define _tar_ver 127
Name:           python-slixmpp
Version:        1.4.2
Release:        bp154.2.3.1
Summary:        Python XMPP (Jabber) Library that Implements Everything as a Plugin
License:        MIT
URL:            https://slixmpp.readthedocs.io/
Source:         https://lab.louiz.org/poezio/slixmpp/-/archive/slix-%{version}/slixmpp-slix-%{version}.tar.gz
# PATCH-FIX-OPENSUSE slixmpp-fix-legacyauth.patch nyov@nexnode.net -- Fix an error in legacyauth support.
Patch0:         %{_name}-fix-legacyauth.patch
# PATCH-FIX-UPSTREAM slixmpp-CVE-2022-45197.patch mvetter@suse.com -- FIX CVE-2022-45197
Patch1:          slixmpp-CVE-2022-45197.patch
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel >= 3.5}
BuildRequires:  %{python_module dnspython}
BuildRequires:  %{python_module xml}
BuildRequires:  fdupes
BuildRequires:  gnupg
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libidn)
Requires:       python-aiohttp
Requires:       python-dnspython
%python_subpackages

%description
Slixmpp is an XMPP library for Python. Based on SleekXMPP, it uses
asyncio instead of threads. XEP (XMPP Extended Protocol) coverage is
realized as plugins.

%prep
%setup -q -n %{_name}-slix-%{version}
%patch0 -p1
%patch1 -p1

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}/

%check
# %%python_exec run_tests.py
%python_exec -munittest discover -v -s tests

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitearch}/%{_name}/
%{python_sitearch}/%{_name}-*

%changelog
* Tue Dec  6 2022 Michael Vetter <mvetter@suse.com>
- bsc#1205433 (CVE-2022-45197) Fix certificate hostname validation
  * Add slixmpp-CVE-2022-45197.patch
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Tue Feb  5 2019 mvetter@suse.com
- Update to 1.4.2:
  * Do not do channel binding without TLS
  * Add default timeout of 120s for IQs (prevent slowdowns)
  * Fix CVE-2019-1000021 (bsc#1124322)
  * Do not query vcard avatars unconditionnally
  * Fix GSSAPI (Jelmer Vernooĳ)
* Fri Jan 11 2019 mvetter@suse.com
- Change source URL from GH to https://lab.louiz.org as requested
* Fri Jan 11 2019 mvetter@suse.com
- Update 1.4.1:
  * jid: Make property aliases proper aliases.
  * stanzabase: Remove python2 legacy.
  * fixing uncaught async exceptions due to missing await
  * XEP-0363: Add a domain argument to discover an upload service
  * XEP-0363: Also check for disco#info’s feature
  * XEP-0030: Don’t call the timeout_callback on each domain
  * Decode bytes in GSSAPI handling, as expected by the kerberos module API
- Update source URL
- Add requires python3-aiohttp: was needed for XEP-0363 since 1.4.0
* Tue Aug 14 2018 sor.alexei@meowr.ru
- Update to version 1.4.0:
  * No changelog available.
- Use python-rpm-macros.
* Fri Jul 20 2018 mcepl@suse.com
- Use python3 -munittest discover -v -s tests instead of run_tests.py
* Thu Jul 19 2018 mcepl@suse.com
- Clean SPEC file
* Sun Feb 11 2018 jengelh@inai.de
- Trim future goals from description, say what it does now.
* Sat Jan 20 2018 sor.alexei@meowr.ru
- Update to version 1.3.0:
  * Implement XEP-0300: Use of Cryptographic Hash Functions in XMPP.
  * Return a Future on clientxmpp.get_roster().
  * Fix custom stanza examples.
  * Fix the HTTP over XMPP and GTalk examples.
  * xmlstream: Warn when the parser is None when data is received.
  * Add an XMPP classifier to setup.py.
  * sasl: Merge two bytes instead of concatenating them at runtime.
  * Fix the port being set to 0 when connecting via hostname.
  * Pass SSL context to plain TLS connections.
  * xmlstream: Remove pygments dumping.
  * XEP-0319: Use the correct timezone.
  * Update RSM for asyncio.
  * Update the MAM plugin for asyncio and the new namespace.
    And add an example.
  * XEP-0054: Fix parsing the BINVAL element.
  * Record the current connection attempt in a future and allow
    cancellation.
  * Add a Markup plugin.
- Add the missing requirement of GnuPG.
- Enable tests.
* Sat Feb 11 2017 sor.alexei@meowr.ru
- Update to version 1.2.4:
  * Test more things before trying to build our stringprep module.
  * XMLStream: Break a long line to make it more readable.
  * Check for XML parsing errors and disconnect in that case.
  * Add missing asyncio.coroutine decorators.
  * Fix a partially-merged Google plugin from the commit acc52fd.
  * Fix an issue with carbons (CVE-2017-5589, bsc#1024690).
* Sat Dec 10 2016 sor.alexei@meowr.ru
- Initial package.
